.. :todo:

========
TODO
========

.. hlist::
    :columns: 2

    - Raise exception if nothing is entered into stdin
    - Write documentation for intro
    - Implement Unit Testing framework with nose
    - Use twine for publishing to PyPI
